pub enum SQuaJLError {
InvalidConfig(String),
DimensionMismatch {
expected: usize,
actual: usize,
},
ZeroNorm,
IncompatibleCode(String),
}Expand description
Error type for clark-hash.
Variants
InvalidConfig(String)
The provided configuration is invalid.
DimensionMismatch
The input vector has the wrong dimension.
ZeroNorm
The vector to encode or sketch was empty or had zero norm.
IncompatibleCode(String)
A quantized code does not match the codec configuration.