pub struct QuantizedVector { /* private fields */ }Expand description
A quantized database-side sketch.
The codes are bit-packed and can be scored asymmetrically against a
QuerySketch.
Implementations
Sourceimpl QuantizedVector
impl QuantizedVector
Sourcepub fn sketch_dim(&self) -> usize
pub fn sketch_dim(&self) -> usize
Returns the number of sketch coordinates.
Sourcepub fn packed_bytes(&self) -> &[u8] ⓘ
pub fn packed_bytes(&self) -> &[u8] ⓘ
Returns the packed bytes that store the quantized sketch.
Sourcepub fn encoded_norm(&self) -> Option<u16>
pub fn encoded_norm(&self) -> Option<u16>
Returns the optional encoded norm channel.
Sourcepub fn storage_bytes(&self) -> usize
pub fn storage_bytes(&self) -> usize
Returns the total number of bytes used by this code.