ClarkHashError

Type Alias ClarkHashError 

pub type ClarkHashError = SQuaJLError;
Package-level name for errors returned by this crate.

Aliased Type

pub enum ClarkHashError {
    InvalidConfig(String),
    DimensionMismatch {
        expected: usize,
        actual: usize,
    },
    ZeroNorm,
    IncompatibleCode(String),
}

Variants



InvalidConfig(String)

The provided configuration is invalid.



DimensionMismatch

The input vector has the wrong dimension.

Fields

expected: usize

Expected dimension.

actual: usize

Actual dimension.



ZeroNorm

The vector to encode or sketch was empty or had zero norm.



IncompatibleCode(String)

A quantized code does not match the codec configuration.